@@ -12,13 +12,18 @@
 
 include ${ESPRESSO_ROOT}/test-suite/ENVIRONMENT
 
+if [ $QE_USE_MPI == 1 ]; then
+  export PARA_PREFIX="mpirun -np ${TESTCODE_NPROCS}"
+else
+  unset PARA_PREFIX
+fi
 
 # Additional stuff before run special test-cases
 
 if test "$2" = "vdw1.in" || test "$1" = "vdw2.in" ; then
    if ! test -f ${ESPRESSO_PSEUDO}/vdW_kernel_table ; then
       echo -n "Generating kernel table - May take several minutes..."
-      ${ESPRESSO_ROOT}/PW/src/generate_vdW_kernel_table.x 
+      ${PARA_PREFIX} ${ESPRESSO_ROOT}/PW/src/generate_vdW_kernel_table.x 
       mv vdW_kernel_table ${ESPRESSO_PSEUDO}/
       echo "kernel table generated in ${ESPRESSO_PSEUDO}/vdW_kernel_table"
    fi
@@ -27,16 +32,12 @@ fi
 if test "$2" = "vdw6.in" ; then
    if ! test -f ${ESPRESSO_PSEUDO}/rVV10_kernel_table ; then
       echo -n "Generating kernel table - May take several minutes..."
-      ${ESPRESSO_ROOT}/PW/src/generate_rVV10_kernel_table.x
+      ${PARA_PREFIX} ${ESPRESSO_ROOT}/PW/src/generate_rVV10_kernel_table.x
       mv rVV10_kernel_table ${ESPRESSO_PSEUDO}/
       echo "kernel table generated in ${ESPRESSO_PSEUDO}/rVV10_kernel_table"
    fi
 fi
 
-# -- Uncomment to run in parallel
-#export PARA_PREFIX="mpirun -np 4"
-unset PARA_PREFIX
-
 ${PARA_PREFIX} ${ESPRESSO_ROOT}/bin/pw.x "$@"
 
 rm -f input_tmp.in
